@@ -66,7 +66,7 @@ class Seti():
         r = requests.post(url=url, json=data,headers={
             "authorization":self.api_key,
             "sign": sign_data
-        })
+        },timeout=10)
         return r.json()
     
     def validate_currency(self,currency:str):
