@@ -21,4 +21,5 @@ class ResponseCreatePayment(BasicResponse):
         self.res=data['res']
         if data['res'] == 200:
             self.data = ResponseCreatePaymentData(data['data'])
-        
\ No newline at end of file
+        else:
+             self.data = ResponseCreatePaymentData({})
\ No newline at end of file
