@@ -19,6 +19,8 @@ class ResponseCreateWallet(BasicResponse):
         self.res=data['res']
         if data['res'] == 200:
             self.data = ResponseCreateWalletData(data['data'])
+        else :
+            self.data =ResponseCreateWalletData()
         
         
 
